==> PhotoDemon-9.0.tar.gz: PhotoDemon-9.0/AUTHORS.md <==
### Primary author

* [Tanner Helland](https://github.com/tannerhelland)

### Patrons

Ongoing development is supported by PhotoDemon's [Patreon members](https://www.patreon.com/photodemon/overview).  Visit [PhotoDemon's Patreon page](https://www.patreon.com/photodemon/overview) to learn more about patron benefits, like [in-depth updates on new PhotoDemon features](https://www.patreon.com/photodemon/posts).

Super Patrons:

* [EFF.ORG](https://www.eff.org/)
* [Jason Brown](https://statslog.com/)
* Jessica H
* Johannes Nendel

Patrons:

* Frank Reibold
* James Proctor
* Jim Schmidt

### 3rd-party libraries

The current PhotoDemon build uses these 3rd-party libraries.  Thank you to these developers for freely sharing their work.  

* [CharLS](https://github.com/team-charls/charls)
* [ExifTool](https://exiftool.org/)
* [EZTwain](http://eztwain.com/eztwain1.htm)
* [FreeImage](https://freeimage.sourceforge.io/)
* [libavif](https://github.com/AOMediaCodec/libavif)
* [libdeflate](https://github.com/ebiggers/libdeflate)
* [libwebp](https://developers.google.com/speed/webp)
* [LittleCMS](http://www.littlecms.com)
* [LZ4](https://lz4.github.io/lz4/)
* [Photoshop-Plugin-Host](https://github.com/spetric/Photoshop-Plugin-Host)
* [resvg](https://github.com/RazrFalcon/resvg)
* [ZStandard](https://github.com/facebook/zstd)

### Direct contributors

The current PhotoDemon release includes source code, translations, artwork, or other contributions from these individuals.  Thank you!

* Abhijit Mhapsekar
* AG Violette
* Alexander Dorn
* Allan Lima
* [Alric Rahl](https://t.me/Alricrahl)
* Andrew Yeoman
* [Ari Sohandri Putra](http://arisohandrip.indonesiaz.com/)
* [Avery](https://github.com/Planet-Source-Code/avery-use-gdi-aka-gdiplus-with-vb6-and-win98__1-37541)
* [Boban Gjerasimoski](https://www.behance.net/Boban_Gjerasimoski)
* [Bonnie West](https://github.com/Planet-Source-Code/bonnie-west-the-optimum-fileexists-function__1-74264)
* [Carles P.V.](https://github.com/Planet-Source-Code/carles-p-v-ibmp-1-2__1-42376)
* ChenLin
* [Chiahong Hong](https://github.com/ChiahongHong)
* [Clment Mariage](https://www.medexprim.com/)
* Cody Robertson
* [Dana Seaman](http://www.cyberactivex.com/)
* DarkAlchy
* Davor ikic
* [Dilettante](http://www.vbforums.com/showthread.php?660014-VB6-ShellPipe-quot-Shell-with-I-O-Redirection-quot-control)
* [Dirk Hartmann](http://www.taichi-zentrum-heidelberg.de)
* [Djordje Djoric](https://www.odesk.com/o/profiles/users/_~0181c1599705edab79/)
* [Easy RGB](http://www.easyrgb.com/)
* [FlatIcons.net](http://flaticons.net/)
* Francis DC
* Frank Donckers
* [Frans van Beers](https://plus.google.com/+FransvanBeers/)
* [Gerry Busch](http://gbusch.altervista.org/)
* [Giorgio "Gibra" Brausi](http://nuke.vbcorner.net)
* [GioRock](https://digilander.libero.it/giorock/)
* [Hans Nolte](https://github.com/hansnolte)
* Helmut Kuerbiss
* Hidayat Suriapermana
* [J. Scott Elblein](https://geekdrop.com)
* [Jason Bullen](https://github.com/Planet-Source-Code/jason-bullen-simple-cubic-spline-curve-plot__1-11488)
* [Jason Peter Brown](https://github.com/jpbro)
* Jean Jacques Piedfort
* [Jerry Huxtable](http://www.jhlabs.com/ip/filters/index.html)
* [Jian Ma](https://www.cnblogs.com/stronghorse/)
* Johannes Nendel
* [John Desrosiers](https://johndesrosiers.com)
* [Jose de TECNORAMA](https://www.tecnorama.es/)
* Joseph Greco
* [Kroc Camen](http://camendesign.com)
* [LaVolpe](http://www.vbforums.com/showthread.php?t=606736)
* [Leandro Ascierto](http://leandroascierto.com/blog/clsmenuimage/)
* [Lemuel Cushing](https://github.com/LemuelCushing)
* Leonid Blyakher
* Manfredi Marceca
* [Manuel Augusto Santos](https://github.com/Planet-Source-Code/manuel-augusto-santos-fast-graphics-filters__1-26303)
* Mariozo
* [Ming](http://ufoym.com/)
* Mohammad Reza Karimi
* [Nguyen Van Hng](https://github.com/vhreal1302)
* [Olaf Schmidt](http://www.vbrichclient.com)
* Old Abiquiu Photographic
* [Paul Bourke](http://paulbourke.net/miscellaneous/)
* Peter Burn
* [pixman library](http://pixman.org/)
* Plinio C Garcia
* [Portablefreeware.com](http://www.portablefreeware.com/forums/viewtopic.php?t=21652)
* [Raj Chaudhuri](https://github.com/rajch)
* [Robert Rayment](http://rrprogs.com/)
* [Ron van Tilburg](https://github.com/Planet-Source-Code/ron-van-tilburg-rvtvbimg__1-14210)
* Roy K (rk)
* Ryszard Cwenar
* Shishi
* [Steve McMahon](http://www.vbaccelerator.com/home/VB/index.asp)
* [Tom Loos](http://www.designedbyinstinct.com)
* [TyraVex](https://github.com/TyraVex)
* [Vatterspun](https://github.com/vatterspun)
* [Vladimir Vissoultchev](https://github.com/wqweto)
* [Will Stampfer](https://github.com/epmatsw)
* [Zhu JinYong](https://github.com/Planet-Source-Code/zhu-jinyong-unicode-browseforfolder__1-73919)

==> PhotoDemon-2024.7.tar.gz: PhotoDemon-2024.7/AUTHORS.md <==
### Primary author

* [Tanner Helland](https://github.com/tannerhelland)

### Patrons

Ongoing development is supported by PhotoDemon's [Patreon members](https://www.patreon.com/photodemon/overview).  Thank you to everyone who supports PhotoDemon's ongoing development!

Super Patrons:

* Johannes Nendel

Patrons:

* Tim Parsons
* Frank Reibold
* Jim Schmidt

### 3rd-party libraries

The current PhotoDemon build uses these 3rd-party libraries.  Thank you to these developers for freely sharing their work.  

* [CharLS](https://github.com/team-charls/charls)
* [ExifTool](https://exiftool.org/)
* [EZTwain](http://eztwain.com/eztwain1.htm)
* [FreeImage](https://freeimage.sourceforge.io/)
* [libavif](https://github.com/AOMediaCodec/libavif)
* [libdeflate](https://github.com/ebiggers/libdeflate)
* [libjxl](https://github.com/libjxl/libjxl)
* [libwebp](https://developers.google.com/speed/webp)
* [LittleCMS](http://www.littlecms.com)
* [LZ4](https://lz4.github.io/lz4/)
* [pdfium](https://pdfium.googlesource.com/pdfium/)
* [Photoshop-Plugin-Host](https://github.com/spetric/Photoshop-Plugin-Host)
* [resvg](https://github.com/RazrFalcon/resvg)
* [ZStandard](https://github.com/facebook/zstd)

### Direct contributors

The current PhotoDemon release includes source code, translations, artwork, or other contributions from these individuals.  Thank you!

* Abhijit Mhapsekar
* AG Violette
* Alexander Dorn
* Allan Lima
* [Alric Rahl](https://t.me/Alricrahl)
* Andrew Yeoman
* [Ari Sohandri Putra](https://github.com/arisohandriputra)
* [Avery](https://github.com/Planet-Source-Code/avery-use-gdi-aka-gdiplus-with-vb6-and-win98__1-37541)
* [Boban Gjerasimoski](https://www.behance.net/Boban_Gjerasimoski)
* [Bonnie West](https://github.com/Planet-Source-Code/bonnie-west-the-optimum-fileexists-function__1-74264)
* [Carles P.V.](https://github.com/Planet-Source-Code/carles-p-v-ibmp-1-2__1-42376)
* [Charltsing](https://www.cnblogs.com/Charltsing/)
* ChenLin
* [Chiahong Hong](https://github.com/ChiahongHong)
* [Clment Mariage](https://www.medexprim.com/)
* Cody Robertson
* [Dana Seaman](http://www.cyberactivex.com/)
* DarkAlchy
* Davor ikic
* [Dilettante](http://www.vbforums.com/showthread.php?660014-VB6-ShellPipe-quot-Shell-with-I-O-Redirection-quot-control)
* [Dirk Hartmann](http://www.taichi-zentrum-heidelberg.de)
* [Djordje Djoric](https://www.odesk.com/o/profiles/users/_~0181c1599705edab79/)
* [Easy RGB](http://www.easyrgb.com/)
* [FlatIcons.net](http://flaticons.net/)
* Francis DC
* Frank Donckers
* [Frans van Beers](https://plus.google.com/+FransvanBeers/)
* [Gerry Busch](http://gbusch.altervista.org/)
* [Giorgio "Gibra" Brausi](http://nuke.vbcorner.net)
* [GioRock](https://digilander.libero.it/giorock/)
* [Hans Nolte](https://github.com/hansnolte)
* Helmut Kuerbiss
* Hidayat Suriapermana
* [J. Scott Elblein](https://geekdrop.com)
* [Jason Bullen](https://github.com/Planet-Source-Code/jason-bullen-simple-cubic-spline-curve-plot__1-11488)
* [Jason Peter Brown](https://github.com/jpbro)
* Jean Jacques Piedfort
* [Jerry Huxtable](http://www.jhlabs.com/ip/filters/index.html)
* [Jian Ma](https://www.cnblogs.com/stronghorse/)
* Johannes Nendel
* [John Desrosiers](https://johndesrosiers.com)
* [Jose de TECNORAMA](https://www.tecnorama.es/)
* Joseph Greco
* [Kenji Hoshimoto (Hosiken)](http://hosiken.jp/)
* [Kroc Camen](http://camendesign.com)
* [LaVolpe](http://www.vbforums.com/showthread.php?t=606736)
* [Leandro Ascierto](http://leandroascierto.com/blog/clsmenuimage/)
* [Lemuel Cushing](https://github.com/LemuelCushing)
* Leonid Blyakher
* Manfredi Marceca
* [Manuel Augusto Santos](https://github.com/Planet-Source-Code/manuel-augusto-santos-fast-graphics-filters__1-26303)
* Mariozo
* [martin19](https://github.com/martin19)
* Miguel Chamorro
* [Ming](http://ufoym.com/)
* Mohammad Reza Karimi
* [Nguyen Van Hng](https://github.com/vhreal1302)
* [Olaf Schmidt](http://www.vbrichclient.com)
* Old Abiquiu Photographic
* [Paul Bourke](http://paulbourke.net/miscellaneous/)
* Peter Burn
* [pixman library](http://pixman.org/)
* Plinio C Garcia
* [Portablefreeware.com](http://www.portablefreeware.com/forums/viewtopic.php?t=21652)
* [Raj Chaudhuri](https://github.com/rajch)
* [Robert Rayment](http://rrprogs.com/)
* [Ron van Tilburg](https://github.com/Planet-Source-Code/ron-van-tilburg-rvtvbimg__1-14210)
* Roy K (rk)
* Ryszard Cwenar
* Shishi
* [Steve McMahon](http://www.vbaccelerator.com/home/VB/index.asp)
* [Tom Loos](http://www.designedbyinstinct.com)
* [TyraVex](https://github.com/TyraVex)
* [Vatterspun](https://github.com/vatterspun)
* [Vladimir Vissoultchev](https://github.com/wqweto)
* [Will Stampfer](https://github.com/epmatsw)
* [Yuriy Balyuk](https://github.com/veksha)
* [Zhu JinYong](https://github.com/Planet-Source-Code/zhu-jinyong-unicode-browseforfolder__1-73919)
